import React, { useState } from "react";
import { StyleSheet, Text, View, Button, TextInput, Image, SafeAreaView, TouchableOpacity, StatusBar, Alert } from "react-native";
import { createUserWithEmailAndPassword } from "firebase/auth";
import { auth } from "../../config/firebase";
import RadioGroup from 'react-native-radio-buttons-group';
const backImage = require("../../assets/backImage.png");
import { collection, addDoc } from "firebase/firestore";
import { database } from "../../config/firebase";


export default function Signup({ navigation }) {
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [name, setName] = useState("");
  const [role, setRole] = useState("")
  const [error, setError] = useState("")

  const onHandleSignup = () => {
    if (!role) { setError("Please choose a role!"); return; }
    if (email !== "" && password !== "") {
      createUserWithEmailAndPassword(auth, email, password)
        .then((userCredential) => {
          addDoc(collection(database, "profiles"), {
            createdAt: new Date(),
            userId: userCredential.user.uid,
            role: role,
            displayName: name,
            avatar: 'https://gravatar.com/avatar/94d45dbdba988afacf30d916e7aaad69?s=200&d=mp&r=x',
          });
        })
        .catch((err) => Alert.alert("Login error", err.message));
    }
  };

  return (
    <View style={styles.container}>
      <Image source={backImage} style={styles.backImage} />
      <View style={styles.whiteSheet} />
      <SafeAreaView style={styles.form}>
        <Text style={styles.title}>Sign Up</Text>
        <TextInput
          style={styles.input}
          placeholder="Your display name"
          autoCapitalize="none"
          autoCorrect={false}
          textContentType="name"
          value={name}
          onChangeText={(text) => setName(text)}
        />
        <TextInput
          style={styles.input}
          placeholder="Enter email"
          autoCapitalize="none"
          keyboardType="email-address"
          textContentType="emailAddress"
          autoFocus={true}
          value={email}
          onChangeText={(text) => setEmail(text)}
        />
        <TextInput
          style={styles.input}
          placeholder="Enter password"
          autoCapitalize="none"
          autoCorrect={false}
          secureTextEntry={true}
          textContentType="password"
          value={password}
          onChangeText={(text) => setPassword(text)}
        />
        <Text>Please choose one role to join us:</Text>
        <RadioGroup
          radioButtons={[
            {
              id: 'cat-owner', // acts as primary key, should be unique and non-empty string
              label: 'Join as a cat owner',
              value: 'cat-owner',
              labelStyle: { color: "black" },
              containerStyle: { width: "100%", marginLeft: 10 }
            },
            {
              id: 'cat-sitter',
              label: 'Join as a cat sitter',
              value: 'cat-sitter',
              labelStyle: { color: "black" },
              containerStyle: { width: "100%", marginLeft: 10 }
            }
          ]}
          onPress={setRole}
          selectedId={role}
        />
        {
          error.length <= 0 && (
            <Text style={{ color: "red" }}>{error}</Text>
          )
        }
        {/* TODO: Add a checkbox for role */}
        <TouchableOpacity style={styles.button} onPress={onHandleSignup}>
          <Text style={{ fontWeight: "bold", color: "#fff", fontSize: 18 }}> Sign Up</Text>
        </TouchableOpacity>
        <View style={{ marginTop: 20, flexDirection: "row", alignItems: "center", alignSelf: "center" }}>
          <Text style={{ color: "gray", fontWeight: "600", fontSize: 14 }}>Don't have an account? </Text>
          <TouchableOpacity onPress={() => navigation.navigate("Login")}>
            <Text style={{ color: "#7444C0", fontWeight: "600", fontSize: 14 }}> Log In</Text>
          </TouchableOpacity>
        </View>
      </SafeAreaView>
      <StatusBar barStyle="light-content" />
    </View>
  );
}
const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: "#fff"
  },
  title: {
    fontSize: 36,
    fontWeight: "bold",
    color: "#7444C0",
    alignSelf: "center",
    paddingBottom: 24
  },
  input: {
    backgroundColor: "#F6F7FB",
    height: 58,
    marginBottom: 20,
    fontSize: 16,
    borderRadius: 10,
    padding: 12
  },
  backImage: {
    width: "100%",
    height: 340,
    position: "absolute",
    top: 0,
    resizeMode: "cover"
  },
  whiteSheet: {
    width: "100%",
    height: "75%",
    position: "absolute",
    bottom: 0,
    backgroundColor: "#fff",
    borderTopLeftRadius: 60
  },
  form: {
    flex: 1,
    justifyContent: "center",
    marginHorizontal: 30
  },
  button: {
    backgroundColor: "#7444C0",
    height: 58,
    borderRadius: 10,
    justifyContent: "center",
    alignItems: "center",
    marginTop: 40
  }
});
